#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
#> This script will install SiemenUMTS components
#> patch: 4.0.5.1.1 
#> Usage: install.sh {-help | -install }
#

# Required values defined
#export PATCH_VER=4.0.5.1.1
#export START_DIR=`pwd`
#export SOURCE_DIR=${FLEXPM_HOME}/patches/${PATCH_VER}
#export BACKUP_DIR=$START_DIR/Backup

MODULE="SieGSM"
RELEASE="4.0.5.1.1"
build_num="2"
PRE_REQ_RELEASE="4.0.5.1.0"
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarFile=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### get ts
#TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup
BackupTarFile=$BACKUP_DIR/archive.${MODULE}_${RP}_UI.tgz



# **************************************************************
# The following are 'standard' routines to be used before
# attempting to apply and upgrade/patch
# **************************************************************
# ***
# Check the essential environment settings have been defined before attempting
# any installation procedures.
# ***
function CheckEnvironment_Install {

  # Check FLEXPM_HOME is defined 
  if [[ -z ${FLEXPM_HOME} || ! -d ${FLEXPM_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check PROSPECT_HOME is defined 
  if [[ -z ${PROSPECT_HOME} || ! -d ${PROSPECT_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check vendor HOME is defined 
  if [[ -z ${SieGSM_HOME} ]]; then
    echo ""
    echo "+> Env variable SieGSM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check that the DB_CONNECT string is defined.
  if [[ -z ${DB_CONNECT} ]]; then
    echo ""
    echo "+> Env variable DB_CONNECT must be set to approriate database connection values."
    echo ""
    exit 1;
  fi
  # Check VENDOR pre-requisite
  PRE_REQ=`show_installed | grep "$MODULE rev $PRE_REQ_RELEASE"`
  if [[ -z ${PRE_REQ} ]]; then
    echo ""
    echo "+> $MODULE $PRE_REQ_RELEASE must be installed before applying this patch."
    echo ""
    exit 1;
  fi
  # Check if trying to re-install...
  CHK_REG=`show_installed | grep "$MODULE rev $RELEASE"`
  if [[ ! -z ${CHK_REG} ]]; then
    echo ""
    echo "+> $MODULE $RELEASE already installed previously.  Quit now!"
    echo ""
    exit 1;
  fi
 
  #check if m/d is up?
  ps-mgr watch once  >/dev/null 2>&1
  # m/d up and running
  if [ $? -eq 0 ]; then
     # chk if sn is running?
     ps-mgr watch once | fgrep sn | fgrep running > /dev/null
     if [ $? -eq 0 ]
     then
       echo ""
       echo "+> The Sentry is still running, please stop the sentry first."
       echo ""
       exit 1
     fi
  fi
}

function CheckEnvironment_UnInstall {

  # Check FLEXPM_HOME is defined
  if [[ -z ${FLEXPM_HOME} || ! -d ${FLEXPM_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check PROSPECT_HOME is defined
  if [[ -z ${PROSPECT_HOME} || ! -d ${PROSPECT_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check vendor HOME is defined
  if [[ -z ${SieGSM_HOME} ]]; then
    echo ""
    echo "+> Env variable SieGSM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check that the DB_CONNECT string is defined.
  if [[ -z ${DB_CONNECT} ]]; then
    echo ""
    echo "+> Env variable DB_CONNECT must be set to approriate database connection values."
    echo ""
    exit 1;
  fi
  # Check if this release installed before or not
  CHK_REG=`show_installed | grep "$MODULE rev $RELEASE"`
  if [[ -z ${CHK_REG} ]]; then
    echo ""
    echo "+> $MODULE $RELEASE not installed previously.  Unable to uninstall!"
    echo ""
    exit 1;
  fi

  if [[ ! -f $BackupTarFile ]]; then
    echo ""
    echo "+> Unable to locate $BackupTarFile to restore.  Failed to uninstall!"
    echo ""
    exit 1;
  fi

  #check if m/d is up?
  ps-mgr watch once  >/dev/null 2>&1
  # m/d up and running
  if [ $? -eq 0 ]; then
     # chk if sn is running?
     ps-mgr watch once | fgrep sn | fgrep running > /dev/null
     if [ $? -eq 0 ]
     then
       echo ""
       echo "+> The Sentry is still running, please stop the sentry first."
       echo ""
       exit 1
     fi
  fi
}

# **************************************************************
# End of routines and start of main patch
# **************************************************************

# Check that the passed parameters are correct
if [[ $# -ne 1 ]]; then
  echo
  echo "Invalid number of arguments"
  echo
  echo "Usage : $0 {-help | -install | -uninstall}"
  echo
  exit;
fi

case $1 in
  -install)
    # Check env settings
    echo ""
    echo "+ Checking environment ..."
    CheckEnvironment_Install
    echo "+ Environment appears to be OK ..."
    echo ""

    #######################################################
    # Installing module...
    #######################################################

    echo
    echo "Registering release number ${RELEASE} ..."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir}/${MODULE}.build
    echo

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $NE_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarFile $NE_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      echo "Installation not complete. Please contact IBM Support."
      exit 2
    fi

    #######################################################
    # rebuild loader
    #######################################################

    echo "+ Performing build_fxload for $MODULE $RELEASE module..."
    cd ${SieGSM_HOME}/vendor/Siemens/GSM/1.3/SieGSM_loader/SIEMENSBSCXML/config
    make build_fxload
    ret=$?

    if [ $ret != 0 ]; then
        echo "+++ build_fxload failed for $MODULE module - aborting!"
        exit 2
    fi
    echo "+ $MODULE $RELEASE build_fxload completed."
    echo ""

    #######################################################
    # recompile all invalid objects (except for views...)
    #######################################################

    echo "Completing registration ..."
    register complete ${SourceDir}/${MODULE}.build

    date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
    echo ""

    break
    ;;
  -uninstall)

    # Check env settings
    echo ""
    echo "+ Checking environment ..."
    CheckEnvironment_UnInstall
    echo "+ Environment appears to be OK ..."
    echo ""

    #######################################################
    # Installing module...
    #######################################################

    echo

    date +"+ Uninstalling Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Restoring from backup files..."

    ${WorkDir}/untar.pl $SourceDir $BackupTarFile $NE_BASE
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      echo "Installation not complete. Please contact IBM Support."
      exit 2
    fi

    #######################################################
    # rebuild loader
    #######################################################

    echo "+ Performing build_fxload for $MODULE $RELEASE module..."
    cd ${SieGSM_HOME}/vendor/Siemens/GSM/1.3/SieGSM_loader/SIEMENSBSCXML/config
    make build_fxload
    ret=$?

    if [ $ret != 0 ]; then
        echo "+++ build_fxload failed for $MODULE module - aborting!"
        exit 2
    fi
    echo "+ $MODULE $RELEASE build_fxload completed."
    echo ""

    #######################################################
    # recompile all invalid objects (except for views...)
    #######################################################

    echo "Unregistering release number ${RELEASE} ..."
    echo "@${WorkDir}/unreg.sql $RELEASE $build_num commit" | sqlplus $DB_CONNECT

    date +"+ $MODULE $RELEASE uninstall is completed at %T, %D"
    echo ""

    break
    ;;
  -help)
    echo
    echo "Usage : $0 {-help | -install}"
    echo
    echo "-help      : Display this help text"
    echo "-install   : Install the patch"
    echo "-uninstall : Uninstall the patch"
    echo
    break
    ;;
  *)
    echo
    echo "Invalid argument supplied"
    echo
    echo "Usage : $0 {-help | -install | -uninstall}"
    echo
    break
    ;;
esac

